@@ -1,6 +1,9 @@
-/* $Id: glibtop_suid.h,v 1.2 2002/08/30 18:58:00 nino Exp $ */
+/* $OpenBSD: glibtop_suid.h,v 1.2 2011/05/23 19:35:53 jasper Exp $	*/
 
-/* Copyright (C) 2002 Nils Nordman <nino@nforced.com>
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
+
+   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
    LibGTop is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
@@ -21,14 +24,24 @@
 #ifndef __GLIBTOP_SUID_H__
 #define __GLIBTOP_SUID_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
+
+#if _IN_LIBGTOP
+#include <sys/param.h>
+#endif
+
+#define KI_PROC(ki) (&(ki))->kp_proc)
+#define KI_EPROC(ki) (&(ki))->kp_eproc)
+
+#define FORCEUREAD	1
+#define UREADOK(ki)	(FORCEUREAD || (KI_PROC(ki)->p_flag & P_INMEM))
 
 static inline void glibtop_suid_enter (glibtop *server) {
-	setreuid (server->machine.uid, server->machine.euid);
+	setregid (server->machine.gid, server->machine.egid);
 };
 
 static inline void glibtop_suid_leave (glibtop *server) {
-	if (setreuid (server->machine.euid, server->machine.uid))
+	if (setregid (server->machine.egid, server->machine.gid))
 		_exit (1);
 };
 
@@ -40,6 +53,6 @@ glibtop_open_p (glibtop *server, const char *program_name,
 		const unsigned long features,
 		const unsigned flags);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
